import { JavaProject, JavaProjectOptions } from "../java";
import { AwsCdkDeps, AwsCdkDepsCommonOptions } from "./awscdk-deps";
import { CdkConfig, CdkConfigCommonOptions } from "./cdk-config";
import { CdkTasks } from "./cdk-tasks";
/**
 * @experimental
 */
export interface AwsCdkJavaAppOptions extends JavaProjectOptions, CdkConfigCommonOptions, AwsCdkDepsCommonOptions {
    /**
     * (experimental) The name of the Java class with the static `main()` method.
     *
     * This method
     * should call `app.synth()` on the CDK app.
     *
     * @default "org.acme.MyApp"
     * @experimental
     */
    readonly mainClass: string;
}
/**
 * (experimental) AWS CDK app in Java.
 *
 * @experimental
 * @pjid awscdk-app-java
 */
export declare class AwsCdkJavaApp extends JavaProject {
    /**
     * (experimental) The `cdk.json` file.
     *
     * @experimental
     */
    readonly cdkConfig: CdkConfig;
    /**
     * (experimental) CDK dependency management helper class.
     *
     * @experimental
     */
    readonly cdkDeps: AwsCdkDeps;
    /**
     * (experimental) The full name of the main class of the java app (package.Class).
     *
     * @experimental
     */
    readonly mainClass: string;
    /**
     * (experimental) CDK tasks.
     *
     * @experimental
     */
    readonly cdkTasks: CdkTasks;
    /**
     * (experimental) The name of the Java package that includes the main class.
     *
     * @experimental
     */
    readonly mainPackage: string;
    /**
     * (experimental) The name of the Java class with the static `main()` method.
     *
     * @experimental
     */
    readonly mainClassName: string;
    /**
     * @experimental
     */
    constructor(options: AwsCdkJavaAppOptions);
    /**
     * (deprecated) Adds an AWS CDK module dependencies.
     *
     * @param modules The list of modules to depend on (e.g. "software.amazon.awscdk/aws-lambda", "software.amazon.awscdk/aws-iam", etc).
     * @deprecated In CDK 2.x all modules are available by default. Alpha modules should be added using the standard 'deps'
     */
    addCdkDependency(...modules: string[]): void;
    private addSample;
}
