import { Component } from "../component";
import { GitHub } from "./github";
/**
 * @experimental
 */
export interface AutoMergeOptions {
    /**
     * (experimental) Number of approved code reviews.
     *
     * @default 1
     * @experimental
     */
    readonly approvedReviews?: number;
    /**
     * (experimental) List of labels that will prevent auto-merging.
     *
     * @default ['do-not-merge']
     * @experimental
     */
    readonly blockingLabels?: string[];
}
/**
 * (experimental) Sets up mergify to merging approved pull requests.
 *
 * If `buildJob` is specified, the specified GitHub workflow job ID is required
 * to succeed in order for the PR to be merged.
 *
 * `approvedReviews` specified the number of code review approvals required for
 * the PR to be merged.
 *
 * @experimental
 */
export declare class AutoMerge extends Component {
    private readonly lazyConditions;
    /**
     * @experimental
     */
    constructor(github: GitHub, options?: AutoMergeOptions);
    /**
     * (experimental) Adds conditions to the auto merge rule.
     *
     * @param conditions The conditions to add (mergify syntax).
     * @experimental
     */
    addConditions(...conditions: string[]): void;
    /**
     * (experimental) Adds conditions that will be rendered only during synthesis.
     *
     * @param later The later.
     * @experimental
     */
    addConditionsLater(later: IAddConditionsLater): void;
    private renderConditions;
}
/**
 * @experimental
 */
export interface IAddConditionsLater {
    /**
     * @experimental
     */
    render(): string[];
}
