import { Component } from "../component";
import { Project } from "../project";
import { Dependabot, DependabotOptions } from "./dependabot";
import { Mergify, MergifyOptions } from "./mergify";
import { PullRequestTemplate } from "./pr-template";
import { PullRequestLintOptions } from "./pull-request-lint";
import { GithubWorkflow } from "./workflows";
/**
 * @experimental
 */
export interface GitHubOptions {
    /**
     * (experimental) Whether mergify should be enabled on this repository or not.
     *
     * @default true
     * @experimental
     */
    readonly mergify?: boolean;
    /**
     * (experimental) Options for Mergify.
     *
     * @default - default options
     * @experimental
     */
    readonly mergifyOptions?: MergifyOptions;
    /**
     * (experimental) Enables GitHub workflows.
     *
     * If this is set to `false`, workflows will not be created.
     *
     * @default true
     * @experimental
     */
    readonly workflows?: boolean;
    /**
     * (experimental) Add a workflow that performs basic checks for pull requests, like validating that PRs follow Conventional Commits.
     *
     * @default true
     * @experimental
     */
    readonly pullRequestLint?: boolean;
    /**
     * (experimental) Options for configuring a pull request linter.
     *
     * @default - see defaults in `PullRequestLintOptions`
     * @experimental
     */
    readonly pullRequestLintOptions?: PullRequestLintOptions;
    /**
     * (experimental) The name of a secret which includes a GitHub Personal Access Token to be used by projen workflows.
     *
     * This token needs to have the `repo`, `workflows`
     * and `packages` scope.
     *
     * @default "PROJEN_GITHUB_TOKEN"
     * @experimental
     */
    readonly projenTokenSecret?: string;
}
/**
 * @experimental
 */
export declare class GitHub extends Component {
    /**
     * (experimental) Returns the `GitHub` component of a project or `undefined` if the project does not have a GitHub component.
     *
     * @experimental
     */
    static of(project: Project): GitHub | undefined;
    /**
     * (experimental) The `Mergify` configured on this repository.
     *
     * This is `undefined` if Mergify
     * was not enabled when creating the repository.
     *
     * @experimental
     */
    readonly mergify?: Mergify;
    /**
     * (experimental) Are workflows enabled?
     *
     * @experimental
     */
    readonly workflowsEnabled: boolean;
    /**
     * (experimental) The name of a secret with a GitHub Personal Access Token to be used by projen workflows.
     *
     * @experimental
     */
    readonly projenTokenSecret: string;
    /**
     * @experimental
     */
    constructor(project: Project, options?: GitHubOptions);
    /**
     * (experimental) All workflows.
     *
     * @experimental
     */
    get workflows(): GithubWorkflow[];
    /**
     * (experimental) Adds a workflow to the project.
     *
     * @param name Name of the workflow.
     * @returns a GithubWorkflow instance
     * @experimental
     */
    addWorkflow(name: string): GithubWorkflow;
    /**
     * @experimental
     */
    addPullRequestTemplate(...content: string[]): PullRequestTemplate;
    /**
     * @experimental
     */
    addDependabot(options?: DependabotOptions): Dependabot;
    /**
     * (experimental) Finds a GitHub workflow by name.
     *
     * Returns `undefined` if the workflow cannot be found.
     *
     * @param name The name of the GitHub workflow.
     * @experimental
     */
    tryFindWorkflow(name: string): undefined | GithubWorkflow;
}
