import { Component } from "../component";
import { IgnoreFile } from "../ignore-file";
import { NodeProject } from "../javascript";
import { Project } from "../project";
/**
 * (experimental) Options for Prettier.
 *
 * @experimental
 */
export interface PrettierOptions {
    /**
     * (experimental) Defines an .prettierIgnore file.
     *
     * @default true
     * @experimental
     */
    readonly ignoreFile?: boolean;
    /**
     * (experimental) Prettier settings.
     *
     * @default - default settings
     * @experimental
     */
    readonly settings?: PrettierSettings;
    /**
     * (experimental) Provide a list of patterns to override prettier configuration.
     *
     * @default []
     * @see https://prettier.io/docs/en/configuration.html#configuration-overrides
     * @experimental
     */
    readonly overrides?: PrettierOverride[];
}
/**
 * (experimental) Options to set in Prettier directly or through overrides.
 *
 * @see https://prettier.io/docs/en/options.html
 * @experimental
 */
export interface PrettierSettings {
    /**
     * (experimental) Include parentheses around a sole arrow function parameter.
     *
     * @default ArrowParens.ALWAYS
     * @experimental
     */
    readonly arrowParens?: ArrowParens;
    /**
     * (experimental) Put > of opening tags on the last line instead of on a new line.
     *
     * @default false
     * @experimental
     */
    readonly bracketSameLine?: boolean;
    /**
     * (experimental) Print spaces between brackets.
     *
     * @default true
     * @experimental
     */
    readonly bracketSpacing?: boolean;
    /**
     * (experimental) Print (to stderr) where a cursor at the given position would move to after formatting.
     *
     * This option cannot be used with --range-start and --range-end.
     *
     * @default -1
     * @experimental
     */
    readonly cursorOffset?: number;
    /**
     * (experimental) Control how Prettier formats quoted code embedded in the file.
     *
     * @default EmbeddedLanguageFormatting.AUTO
     * @experimental
     */
    readonly embeddedLanguageFormatting?: EmbeddedLanguageFormatting;
    /**
     * (experimental) Which end of line characters to apply.
     *
     * @default EndOfLine.LF
     * @experimental
     */
    readonly endOfLine?: EndOfLine;
    /**
     * (experimental) Specify the input filepath.
     *
     * This will be used to do parser inference.
     *
     * @default none
     * @experimental
     */
    readonly filepath?: string;
    /**
     * (experimental) How to handle whitespaces in HTML.
     *
     * @default HTMLWhitespaceSensitivity.CSS
     * @experimental
     */
    readonly htmlWhitespaceSensitivity?: HTMLWhitespaceSensitivity;
    /**
     * (experimental) Insert @format pragma into file's first docblock comment.
     *
     * @default false
     * @experimental
     */
    readonly insertPragma?: boolean;
    /**
     * (experimental) Use single quotes in JSX.
     *
     * @default false
     * @experimental
     */
    readonly jsxSingleQuote?: boolean;
    /**
     * (experimental) Which parser to use.
     *
     * @default - Prettier automatically infers the parser from the input file path, so you shouldn’t have to change this setting.
     * @experimental
     */
    readonly parser?: string;
    /**
     * (experimental) Add a plugin.
     *
     * Multiple plugins can be passed as separate `--plugin`s.
     *
     * @default []
     * @experimental
     */
    readonly plugins?: string[];
    /**
     * (experimental) Custom directory that contains prettier plugins in node_modules subdirectory.
     *
     * Overrides default behavior when plugins are searched relatively to the location of
     * Prettier.
     * Multiple values are accepted.
     *
     * @default []
     * @experimental
     */
    readonly pluginSearchDirs?: string[];
    /**
     * (experimental) The line length where Prettier will try wrap.
     *
     * @default 80
     * @experimental
     */
    readonly printWidth?: number;
    /**
     * (experimental) How to wrap prose.
     *
     * @default ProseWrap.PRESERVE
     * @experimental
     */
    readonly proseWrap?: ProseWrap;
    /**
     * (experimental) Change when properties in objects are quoted.
     *
     * @default QuoteProps.ASNEEDED
     * @experimental
     */
    readonly quoteProps?: QuoteProps;
    /**
     * (experimental) Format code ending at a given character offset (exclusive).
     *
     * The range will extend forwards to the end of the selected statement.
     * This option cannot be used with --cursor-offset.
     *
     * @default null
     * @experimental
     */
    readonly rangeEnd?: number;
    /**
     * (experimental) Format code starting at a given character offset.
     *
     * The range will extend backwards to the start of the first line containing the selected
     * statement.
     * This option cannot be used with --cursor-offset.
     *
     * @default 0
     * @experimental
     */
    readonly rangeStart?: number;
    /**
     * (experimental) Require either '@prettier' or '@format' to be present in the file's first docblock comment in order for it to be formatted.
     *
     * @default false
     * @experimental
     */
    readonly requirePragma?: boolean;
    /**
     * (experimental) Print semicolons.
     *
     * @default true
     * @experimental
     */
    readonly semi?: boolean;
    /**
     * (experimental) Use single quotes instead of double quotes.
     *
     * @default false
     * @experimental
     */
    readonly singleQuote?: boolean;
    /**
     * (experimental) Number of spaces per indentation level.
     *
     * @default 2
     * @experimental
     */
    readonly tabWidth?: number;
    /**
     * (experimental) Print trailing commas wherever possible when multi-line.
     *
     * @default TrailingComma.ES5
     * @experimental
     */
    readonly trailingComma?: TrailingComma;
    /**
     * (experimental) Indent with tabs instead of spaces.
     *
     * @default false
     * @experimental
     */
    readonly useTabs?: boolean;
    /**
     * (experimental) Indent script and style tags in Vue files.
     *
     * @default false
     * @experimental
     */
    readonly vueIndentScriptAndStyle?: boolean;
}
/**
 * @experimental
 */
export declare enum ArrowParens {
    /**
     * (experimental) Always include parens.
     *
     * Example: `(x) => x`
     *
     * @experimental
     */
    ALWAYS = "always",
    /**
     * (experimental) Omit parens when possible.
     *
     * Example: `x => x`
     *
     * @experimental
     */
    AVOID = "avoid"
}
/**
 * @experimental
 */
export declare enum EmbeddedLanguageFormatting {
    /**
     * (experimental) Format embedded code if Prettier can automatically identify it.
     *
     * @experimental
     */
    AUTO = "auto",
    /**
     * (experimental) Never automatically format embedded code.
     *
     * @experimental
     */
    OFF = "off"
}
/**
 * @experimental
 */
export declare enum EndOfLine {
    /**
     * (experimental) Maintain existing (mixed values within one file are normalised by looking at what's used after the first line).
     *
     * @experimental
     */
    AUTO = "auto",
    /**
     * (experimental) Carriage Return character only (\r), used very rarely.
     *
     * @experimental
     */
    CR = "cr",
    /**
     * (experimental) Carriage Return + Line Feed characters (\r\n), common on Windows.
     *
     * @experimental
     */
    CRLF = "crlf",
    /**
     * (experimental) Line Feed only (\n), common on Linux and macOS as well as inside git repos.
     *
     * @experimental
     */
    LF = "lf"
}
/**
 * @experimental
 */
export declare enum HTMLWhitespaceSensitivity {
    /**
     * (experimental) Respect the default value of CSS display property.
     *
     * @experimental
     */
    CSS = "css",
    /**
     * (experimental) Whitespaces are considered insignificant.
     *
     * @experimental
     */
    IGNORE = "ignore",
    /**
     * (experimental) Whitespaces are considered significant.
     *
     * @experimental
     */
    STRICT = "strict"
}
/**
 * @experimental
 */
export interface PrettierOverride {
    /**
     * (experimental) Exclude these files from this override.
     *
     * @experimental
     */
    readonly excludeFiles?: Files;
    /**
     * (experimental) Include these files in this override.
     *
     * @experimental
     */
    readonly files: Files;
    /**
     * (experimental) The options to apply for this override.
     *
     * @experimental
     */
    readonly settings: PrettierSettings;
}
/**
 * Exclude these files from this override.
 *
 * Include these files in this override.
 */
export declare type Files = string[] | string;
/**
 * @experimental
 */
export declare enum ProseWrap {
    /**
     * (experimental) Wrap prose if it exceeds the print width.
     *
     * @experimental
     */
    ALWAYS = "always",
    /**
     * (experimental) Do not wrap prose.
     *
     * @experimental
     */
    NEVER = "never",
    /**
     * (experimental) Wrap prose as-is.
     *
     * @experimental
     */
    PRESERVE = "preserve"
}
/**
 * @experimental
 */
export declare enum QuoteProps {
    /**
     * (experimental) Only add quotes around object properties where required.
     *
     * @experimental
     */
    ASNEEDED = "as-needed",
    /**
     * (experimental) If at least one property in an object requires quotes, quote all properties.
     *
     * @experimental
     */
    CONSISTENT = "consistent",
    /**
     * (experimental) Respect the input use of quotes in object properties.
     *
     * @experimental
     */
    PRESERVE = "preserve"
}
/**
 * @experimental
 */
export declare enum TrailingComma {
    /**
     * (experimental) Trailing commas wherever possible (including function arguments).
     *
     * @experimental
     */
    ALL = "all",
    /**
     * (experimental) Trailing commas where valid in ES5 (objects, arrays, etc.).
     *
     * @experimental
     */
    ES5 = "es5",
    /**
     * (experimental) No trailing commas.
     *
     * @experimental
     */
    NONE = "none"
}
/**
 * (experimental) Represents prettier configuration.
 *
 * @experimental
 */
export declare class Prettier extends Component {
    /**
     * @experimental
     */
    static of(project: Project): Prettier | undefined;
    /**
     * (experimental) Direct access to the prettier settings.
     *
     * @experimental
     */
    readonly settings: PrettierSettings;
    /**
     * (experimental) The .prettierIgnore file.
     *
     * @experimental
     */
    readonly ignoreFile?: IgnoreFile;
    /**
     * Direct access to the prettier overrides
     *
     * @internal
     */
    private readonly _overrides;
    /**
     * @experimental
     */
    constructor(project: NodeProject, options: PrettierOptions);
    /**
     * (experimental) Add a prettier override.
     *
     * @see https://prettier.io/docs/en/configuration.html#configuration-overrides
     * @experimental
     */
    addOverride(override: PrettierOverride): void;
    /**
     * (experimental) Defines Prettier ignore Patterns these patterns will be added to the file .prettierignore.
     *
     * @param pattern filepatterns so exclude from prettier formatting.
     * @experimental
     */
    addIgnorePattern(pattern: string): void;
    /**
     * (experimental) Access to the Prettieroverrides to extend those.
     *
     * @experimental
     */
    get overrides(): PrettierOverride[];
    /**
     * (experimental) Called before synthesis.
     *
     * @experimental
     */
    preSynthesize(): void;
}
