import { Eslint, EslintOptions, NodeProject, NodeProjectOptions, TypescriptConfig, TypescriptConfigOptions } from "../javascript";
import { Task } from "../task";
import { ProjenrcOptions as ProjenrcTsOptions } from "../typescript";
/**
 * @experimental
 */
export interface TypeScriptProjectOptions extends NodeProjectOptions {
    /**
     * (experimental) Typescript  artifacts output directory.
     *
     * @default "lib"
     * @experimental
     */
    readonly libdir?: string;
    /**
     * (experimental) Typescript sources directory.
     *
     * @default "src"
     * @experimental
     */
    readonly srcdir?: string;
    /**
     * (experimental) Jest tests directory. Tests files should be named `xxx.test.ts`.
     *
     * If this directory is under `srcdir` (e.g. `src/test`, `src/__tests__`),
     * then tests are going to be compiled into `lib/` and executed as javascript.
     * If the test directory is outside of `src`, then we configure jest to
     * compile the code in-memory.
     *
     * @default "test"
     * @experimental
     */
    readonly testdir?: string;
    /**
     * (experimental) Setup eslint.
     *
     * @default true
     * @experimental
     */
    readonly eslint?: boolean;
    /**
     * (experimental) Eslint options.
     *
     * @default - opinionated default options
     * @experimental
     */
    readonly eslintOptions?: EslintOptions;
    /**
     * (experimental) TypeScript version to use.
     *
     * NOTE: Typescript is not semantically versioned and should remain on the
     * same minor, so we recommend using a `~` dependency (e.g. `~1.2.3`).
     *
     * @default "latest"
     * @experimental
     */
    readonly typescriptVersion?: string;
    /**
     * (experimental) Docgen by Typedoc.
     *
     * @default false
     * @experimental
     */
    readonly docgen?: boolean;
    /**
     * (experimental) Docs directory.
     *
     * @default "docs"
     * @experimental
     */
    readonly docsDirectory?: string;
    /**
     * (experimental) Custom TSConfig.
     *
     * @default - default options
     * @experimental
     */
    readonly tsconfig?: TypescriptConfigOptions;
    /**
     * (experimental) Custom tsconfig options for the development tsconfig.json file (used for testing).
     *
     * @default - use the production tsconfig options
     * @experimental
     */
    readonly tsconfigDev?: TypescriptConfigOptions;
    /**
     * (experimental) The name of the development tsconfig.json file.
     *
     * @default "tsconfig.dev.json"
     * @experimental
     */
    readonly tsconfigDevFile?: string;
    /**
     * (experimental) Do not generate a `tsconfig.json` file (used by jsii projects since tsconfig.json is generated by the jsii compiler).
     *
     * @default false
     * @experimental
     */
    readonly disableTsconfig?: boolean;
    /**
     * (experimental) Generate one-time sample in `src/` and `test/` if there are no files there.
     *
     * @default true
     * @experimental
     */
    readonly sampleCode?: boolean;
    /**
     * (experimental) The .d.ts file that includes the type declarations for this module.
     *
     * @default - .d.ts file derived from the project's entrypoint (usually lib/index.d.ts)
     * @experimental
     */
    readonly entrypointTypes?: string;
    /**
     * (experimental) Use TypeScript for your projenrc file (`.projenrc.ts`).
     *
     * @default false
     * @experimental
     */
    readonly projenrcTs?: boolean;
    /**
     * (experimental) Options for .projenrc.ts.
     *
     * @experimental
     */
    readonly projenrcTsOptions?: ProjenrcTsOptions;
}
/**
 * (experimental) TypeScript project.
 *
 * @experimental
 * @pjid typescript
 */
export declare class TypeScriptProject extends NodeProject {
    /**
     * @experimental
     */
    readonly docgen?: boolean;
    /**
     * @experimental
     */
    readonly docsDirectory: string;
    /**
     * @experimental
     */
    readonly eslint?: Eslint;
    /**
     * @experimental
     */
    readonly tsconfigEslint?: TypescriptConfig;
    /**
     * @experimental
     */
    readonly tsconfig?: TypescriptConfig;
    /**
     * (experimental) A typescript configuration file which covers all files (sources, tests, projen).
     *
     * @experimental
     */
    readonly tsconfigDev: TypescriptConfig;
    /**
     * (experimental) The directory in which the .ts sources reside.
     *
     * @experimental
     */
    readonly srcdir: string;
    /**
     * (experimental) The directory in which compiled .js files reside.
     *
     * @experimental
     */
    readonly libdir: string;
    /**
     * (experimental) The directory in which tests reside.
     *
     * @experimental
     */
    readonly testdir: string;
    /**
     * (experimental) The "watch" task.
     *
     * @experimental
     */
    readonly watchTask: Task;
    /**
     * @experimental
     */
    constructor(options: TypeScriptProjectOptions);
    /**
     * Tests are compiled to `lib/TESTDIR`, so we don't need jest to compile them
     * for us. just run them directly from javascript.
     */
    private addJestCompiled;
    private addJestNoCompile;
}
/**
 * (experimental) TypeScript app.
 *
 * @experimental
 * @pjid typescript-app
 */
export declare class TypeScriptAppProject extends TypeScriptProject {
    /**
     * @experimental
     */
    constructor(options: TypeScriptProjectOptions);
}
/**
 * @deprecated use `TypeScriptProject`
 */
export declare class TypeScriptLibraryProject extends TypeScriptProject {
}
/**
 * @deprecated use TypeScriptProjectOptions
 */
export interface TypeScriptLibraryProjectOptions extends TypeScriptProjectOptions {
}
/**
 * @internal
 */
export declare function mergeTsconfigOptions(...options: (TypescriptConfigOptions | undefined)[]): TypescriptConfigOptions;
